BetterPlayerAsmsTrack class

Represents HLS / DASH track which can be played within player

Constructors

BetterPlayerAsmsTrack(String? id, int? width, int? height, int? bitrate, int? frameRate, String? codecs, String? mimeType)
BetterPlayerAsmsTrack.defaultTrack()
factory

Properties

bitrate → int?
Bitrate in px of the track
final
codecs → String?
Codecs of the track
final
frameRate → int?
Frame rate of the track
final
hashCode → int
The hash code for this object.
no setteroverride
height → int?
Height in px of the track
final
id → String?
Id of the track
final
mimeType → String?
mimeType of the video track
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int?
Width in px of the track
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override