BetterPlayerDrmConfiguration class

Configuration of DRM used to protect data source

Constructors

BetterPlayerDrmConfiguration({BetterPlayerDrmType? drmType, String? token, String? licenseUrl, String? certificateUrl, Map<String, String>? headers, String? clearKey})

Properties

certificateUrl → String?
Url of fairplay certificate
final
clearKey → String?
ClearKey json object, used only for ClearKey protection. Only support for Android.
final
drmType → BetterPlayerDrmType?
Type of DRM
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>?
Additional headers send with auth request, used only for WIDEVINE DRM
final
licenseUrl → String?
Url of license server
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String?
Parameter used only for token encrypted DRMs
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited